@@ -4,7 +4,7 @@ from flask import Flask, request, jsonify, send_file
 from rq.exceptions import NoSuchJobError
 
 from label_studio.ml.model import LabelStudioMLManager
-from label_studio.utils.misc import exception_treatment
+from label_studio.utils.misc import exception_handler
 
 logger = logging.getLogger(__name__)
 
@@ -19,7 +19,7 @@ def init_app(model_class, **kwargs):
 
 
 @_server.route('/predict', methods=['POST'])
-@exception_treatment
+@exception_handler
 def _predict():
     data = request.json
     tasks = data['tasks']
@@ -37,7 +37,7 @@ def _predict():
 
 
 @_server.route('/setup', methods=['POST'])
-@exception_treatment
+@exception_handler
 def _setup():
     data = request.json
     project = data.get('project')
@@ -49,7 +49,7 @@ def _setup():
 
 
 @_server.route('/train', methods=['POST'])
-@exception_treatment
+@exception_handler
 def _train():
     data = request.json
     completions = data['completions']
@@ -64,7 +64,7 @@ def _train():
 
 
 @_server.route('/is_training', methods=['GET'])
-@exception_treatment
+@exception_handler
 def _is_training():
     project = request.args.get('project')
     output = _manager.is_training(project)
@@ -72,13 +72,13 @@ def _is_training():
 
 
 @_server.route('/health', methods=['GET'])
-@exception_treatment
+@exception_handler
 def health():
     return jsonify({'status': 'UP', 'model_dir': _manager.model_dir})
 
 
 @_server.route('/metrics', methods=['GET'])
-@exception_treatment
+@exception_handler
 def metrics():
     return jsonify({})
 
