@@ -9,9 +9,11 @@ import calendar
 import pytz
 import flask
 import socket
-import errno
+import requests
+import label_studio
+
+from pkg_resources import parse_version
 
-from json import JSONEncoder
 from collections import defaultdict, OrderedDict
 from lxml import etree, objectify
 from datetime import datetime
@@ -56,7 +58,7 @@ class AnswerException(Exception):
 
 
 # standard exception treatment for any api function
-def exception_treatment(f):
+def exception_handler(f):
     def exception_f(*args, **kwargs):
         try:
             return f(*args, **kwargs)
@@ -83,7 +85,7 @@ def exception_treatment(f):
 
 
 # standard exception treatment for any page function
-def exception_treatment_page(f):
+def exception_handler_page(f):
     def exception_f(*args, **kwargs):
         try:
             return f(*args, **kwargs)
@@ -91,6 +93,7 @@ def exception_treatment_page(f):
             error = str(e)
             traceback = tb.format_exc()
             logger.debug(traceback)
+            print(traceback)
             return flask.render_template(
                 'includes/error.html',
                 error=error, header="Project loading error", traceback=traceback)
@@ -131,6 +134,10 @@ def get_app_version():
     return pkg_resources.get_distribution('label-studio').version
 
 
+_LABEL_TAGS = {'Label', 'Choice'}
+_NOT_CONTROL_TAGS = {'Filter',}
+
+
 def parse_config(config_string):
     """
     :param config_string: Label config string
@@ -149,14 +156,11 @@ def parse_config(config_string):
     if not config_string:
         return {}
 
-    LABEL_TAGS = {'Label', 'Choice'}
-    NOT_CONTROL_TAGS = {'Filter',}
-
     def _is_input_tag(tag):
         return tag.attrib.get('name') and tag.attrib.get('value')
 
     def _is_output_tag(tag):
-        return tag.attrib.get('name') and tag.attrib.get('toName') and tag.tag not in NOT_CONTROL_TAGS
+        return tag.attrib.get('name') and tag.attrib.get('toName') and tag.tag not in _NOT_CONTROL_TAGS
 
     def _get_parent_output_tag_name(tag, outputs):
         # Find parental <Choices> tag for nested tags like <Choices><View><View><Choice>...
@@ -171,13 +175,13 @@ def parse_config(config_string):
 
     xml_tree = etree.fromstring(config_string)
 
-    inputs, outputs, labels = {}, {}, defaultdict(set)
+    inputs, outputs, labels = {}, {}, defaultdict(dict)
     for tag in xml_tree.iter():
         if _is_output_tag(tag):
             outputs[tag.attrib['name']] = {'type': tag.tag, 'to_name': tag.attrib['toName'].split(',')}
         elif _is_input_tag(tag):
             inputs[tag.attrib['name']] = {'type': tag.tag, 'value': tag.attrib['value'].lstrip('$')}
-        if tag.tag not in LABEL_TAGS:
+        if tag.tag not in _LABEL_TAGS:
             continue
         parent_name = _get_parent_output_tag_name(tag, outputs)
         if parent_name is not None:
@@ -187,7 +191,7 @@ def parse_config(config_string):
                     'Inspecting tag {tag_name}... found no "value" or "alias" attributes.'.format(
                         tag_name=etree.tostring(tag, encoding='unicode').strip()[:50]))
             else:
-                labels[parent_name].add(actual_value)
+                labels[parent_name][actual_value] = dict(tag.attrib)
     for output_tag, tag_info in outputs.items():
         tag_info['inputs'] = []
         for input_tag_name in tag_info['to_name']:
@@ -197,10 +201,15 @@ def parse_config(config_string):
                                .format(input_tag_name=input_tag_name, output_tag=output_tag))
             tag_info['inputs'].append(inputs[input_tag_name])
         tag_info['labels'] = list(labels[output_tag])
+        tag_info['labels_attrs'] = labels[output_tag]
     logger.debug('Parsed config:\n' + json.dumps(outputs, indent=2))
     return outputs
 
 
+def parse_label_attrs(config_string):
+    xml_tree = etree.fromstring(config_string)
+
+
 def iter_config_templates(templates_dir=None):
     try:
         templates_dir = find_dir('examples') if templates_dir is None else find_dir(templates_dir)
@@ -355,3 +364,40 @@ def check_port_in_use(host, port):
     host = host.replace('https://', '').replace('http://', '')
     with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
         return s.connect_ex((host, port)) == 0
+
+
+def start_browser(ls_url, no_browser):
+    import threading
+    import webbrowser
+    if no_browser:
+        return
+
+    browser_url = ls_url + '/welcome'
+    threading.Timer(2.5, lambda: webbrowser.open(browser_url)).start()
+    print('Start browser at URL: ' + browser_url)
+
+
+def get_latest_version():
+    pypi_url = 'https://pypi.org/pypi/%s/json' % label_studio.package_name
+    try:
+        response = requests.get(pypi_url).text
+        latest_version = json.loads(response)['info']['version']
+    except Exception as exc:
+        logger.error("Can't get latest version.", exc_info=True)
+    else:
+        return latest_version
+
+
+def current_version_is_outdated(latest_version):
+    latest_version = parse_version(latest_version)
+    current_version = parse_version(label_studio.__version__)
+    return current_version < latest_version
+
+
+def str2datetime(timestamp_str):
+    try:
+        ts = int(timestamp_str)
+    except:
+        return timestamp_str
+    # return datetime.utcfromtimestamp(ts).strftime('%Y%m%d.%H%M%S')
+    return datetime.utcfromtimestamp(ts).strftime('%c')
